@@ -385,6 +385,7 @@ def pyrogram_api():
             ChatJoiner
             Dialog
             Restriction
+            EmojiStatus
         """,
         messages_media="""
         Messages & Media
@@ -413,6 +414,8 @@ def pyrogram_api():
             VideoChatEnded
             VideoChatMembersInvited
             WebAppData
+            MessageReactions
+            ChatReactions
         """,
         bot_keyboards="""
         Bot keyboards
